@@ -57,3 +57,31 @@ bugzilla \
         sprintf ("=item L<https://bugzilla.redhat.com/%s>\n\n%s\n",
                  $1, $2)
         }xe'
+
+# We can't fetch Jira subjects or github issues, but we can at least
+# list them.
+jiraids=$(
+    git log "$1" |
+    grep -Eio 'RHEL-[0-9]+' |
+    sort -u
+)
+
+for id in $jiraids ; do
+    echo "=item L<https://issues.redhat.com/browse/$id>"
+    echo
+    echo "XXX"
+    echo
+done
+
+issues=$(
+    git log "$1" |
+    grep -Eio 'https?://github\.com/libguestfs/virt-v2v/issues/[0-9]+' |
+    sort -u
+)
+
+for issue in $issues ; do
+    echo "=item L<$issue>"
+    echo
+    echo "XXX"
+    echo
+done
