@@ -37,6 +37,7 @@ type options = {
   network_map : Networks.t;
   root_choice : root_choice;
   static_ips : static_ip list;
+  customize_ops : Customize_cmdline.ops;
 }
 
 (* Mountpoint stats, used for free space estimation. *)
@@ -91,6 +92,9 @@ let rec convert dir options source =
     do_convert g source inspect i_firmware
       options.block_driver options.keep_serial_console options.static_ips in
 
+  (* Run virt-customize options. *)
+  Customize_run.run g inspect.i_root options.customize_ops;
+
   g#umount_all ();
 
   (* Doing fstrim on all the filesystems reduces the transfer size
@@ -118,6 +122,9 @@ let rec convert dir options source =
   (* Create target metadata file. *)
   let target_meta = { guestcaps; target_buses; target_firmware; target_nics } in
 
+  (* This is a good place to dump everything we know about the guest. *)
+  if verbose () then debug_info source inspect target_meta mpstats;
+
   (* Return inspection data and target metadata. *)
   inspect, target_meta
 
@@ -130,20 +137,8 @@ and get_mpstats g =
       { mp_dev = dev; mp_path = path; mp_statvfs = statvfs; mp_vfs = vfs }
   ) (g#mountpoints ()) in
 
-  if verbose () then (
-    (* This is useful for debugging speed / fstrim issues. *)
-    eprintf "mpstats:\n";
-    List.iter (print_mpstat Stdlib.stderr) mpstats
-  );
-
   mpstats
 
-and print_mpstat chan { mp_dev = dev; mp_path = path;
-                        mp_statvfs = s; mp_vfs = vfs } =
-  fprintf chan "mountpoint statvfs %s %s (%s):\n" dev path vfs;
-  fprintf chan "  bsize=%Ld blocks=%Ld bfree=%Ld bavail=%Ld\n"
-    s.Guestfs.bsize s.Guestfs.blocks s.Guestfs.bfree s.Guestfs.bavail
-
 (* Conversion can fail if there is no space on the guest filesystems
  * (RHBZ#1139543).  To avoid this situation, check there is some
  * headroom.  Mainly we care about the root filesystem.
@@ -212,6 +207,7 @@ and do_fstrim g inspect =
         with G.Error _ -> false in
 
       if mounted then (
+        debug "info: trimming %s" dev;
         try g#fstrim "/"
         with G.Error msg ->
           warning (f_"fstrim on guest filesystem %s failed.  Usually you \
@@ -224,19 +220,23 @@ and do_fstrim g inspect =
 (* Conversion. *)
 and do_convert g source inspect i_firmware
                block_driver keep_serial_console interfaces =
-  (match inspect.i_product_name with
-  | "unknown" ->
+  (match inspect.i_product_name, inspect.i_osinfo with
+  | "unknown", "unknown" ->
     message (f_"Converting the guest to run on KVM")
-  | prod ->
+  | "unknown", osinfo ->
+    message (f_"Converting %s guest to run on KVM") osinfo
+  | prod, "unknown" ->
     message (f_"Converting %s to run on KVM") prod
+  | prod, osinfo ->
+    message (f_"Converting %s (%s) to run on KVM") prod osinfo
   );
 
   let convert, conversion_name =
     match inspect with
     | { i_type = "linux";
         i_distro = ("fedora"
-                    | "rhel" | "centos" | "scientificlinux" | "redhat-based"
-                    | "oraclelinux" | "rocky"
+                    | "rhel" | "centos" | "circle" | "scientificlinux"
+                    | "redhat-based" | "oraclelinux" | "rocky"
                     | "sles" | "suse-based" | "opensuse"
                     | "altlinux"
                     | "debian" | "ubuntu" | "linuxmint" | "kalilinux") } ->
@@ -281,3 +281,28 @@ and get_target_firmware i_firmware guestcaps source output =
    | TargetUEFI -> info (f_"This guest requires UEFI on the target to boot."));
 
   target_firmware
+
+(* After conversion we dump as much information about the guest
+ * as we can in one place.  Note this is only called when verbose
+ * is enabled.
+ *)
+and debug_info source inspect
+               { guestcaps; target_buses; target_firmware; target_nics }
+               mpstats =
+  eprintf "info:\n";
+  eprintf "%s\n" (string_of_source source);
+  eprintf "%s\n" (string_of_inspect inspect);
+  eprintf "%s\n" (string_of_guestcaps guestcaps);
+  eprintf "%s\n" (string_of_target_buses target_buses);
+  eprintf "target firmware: %s\n" (string_of_target_firmware target_firmware);
+  eprintf "target NICs:\n";
+  List.iter (fun nic -> eprintf "%s\n" (string_of_source_nic nic))
+    target_nics;
+  eprintf "mountpoint stats:\n";
+  List.iter debug_mpstat mpstats;
+
+and debug_mpstat { mp_dev = dev; mp_path = path;
+                   mp_statvfs = s; mp_vfs = vfs } =
+  eprintf "    mountpoint statvfs %s %s (%s):\n" dev path vfs;
+  eprintf "        bsize=%Ld blocks=%Ld bfree=%Ld bavail=%Ld\n"
+    s.Guestfs.bsize s.Guestfs.blocks s.Guestfs.bfree s.Guestfs.bavail
