@@ -49,7 +49,7 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
   let family =
     match inspect.i_distro with
     | "fedora"
-    | "rhel" | "centos" | "scientificlinux" | "redhat-based"
+    | "rhel" | "centos" | "circle" | "scientificlinux" | "redhat-based"
     | "oraclelinux" | "rocky" -> `RHEL_family
     | "altlinux" -> `ALT_family
     | "sles" | "suse-based" | "opensuse" -> `SUSE_family
@@ -68,8 +68,8 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
 
   let qga_svc_start_cmd family distro major =
     match family, distro, major with
-    | `RHEL_family, ( "rhel" | "centos" | "scientificlinux" | "redhat-based" |
-                      "oraclelinux" | "rocky" ), 6 ->
+    | `RHEL_family, ( "rhel" | "centos" | "circle" | "scientificlinux" |
+                      "redhat-based" | "oraclelinux" | "rocky" ), 6 ->
       (* https://bugzilla.redhat.com/show_bug.cgi?id=2028764#c52 *)
       Some "service qemu-ga start"
 
@@ -163,8 +163,6 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
     configure_kernel_modules block_type net_type;
     rebuild_initrd kernel;
 
-    SELinux_relabel.relabel g;
-
     let machine, virtio_1_0 =
       match inspect.i_arch with
       | ("i386"|"x86_64") ->
@@ -183,8 +181,8 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
             *)
            (match inspect.i_distro, inspect.i_major_version with
             | "fedora", _ -> Q35
-            | ("rhel"|"centos"|"scientificlinux"|"redhat-based"|"oraclelinux"|
-               "rocky"), major ->
+            | ("rhel"|"centos"|"circle"|"scientificlinux"|"redhat-based"|
+               "oraclelinux"|"rocky"), major ->
               if major <= 4 then I440FX else Q35
             | ("sles"|"suse-based"|"opensuse"), major ->
               if major < 10 then I440FX else Q35
@@ -700,8 +698,9 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
       let kernels = List.rev kernels (* so best is first *) in
       List.hd kernels in
     if verbose () then (
-      eprintf "best kernel for this guest:\n";
-      print_kernel_info stderr "\t" best_kernel
+      eprintf "info: best kernel for this guest:\n";
+      print_kernel_info stderr "\t" best_kernel;
+      flush stderr
     );
     if best_kernel <> List.hd bootloader_kernels then (
       debug "best kernel is not the bootloader default, \
@@ -1204,7 +1203,7 @@ let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
       ) in
 
     if verbose () then (
-      eprintf "block device map:\n";
+      eprintf "info: block device map:\n";
       List.iter (
         fun (source_dev, target_dev) ->
           eprintf "\t%s\t-> %s\n" source_dev target_dev
