@@ -38,7 +38,8 @@ module G = Guestfs
  * time the Windows VM is booted on KVM.
  *)
 
-let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
+let convert (g : G.guestfs) source inspect i_firmware
+      block_driver _ static_ips =
   (*----------------------------------------------------------------------*)
   (* Inspect the Windows guest. *)
 
@@ -272,6 +273,8 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
     Registry.with_hive_write g inspect.i_windows_software_hive
                              update_software_hive;
 
+    configure_online_disks block_driver;
+
     configure_network_interfaces net_driver;
 
     fix_ntfs_heads ();
@@ -357,6 +360,12 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
                   may want to install the guest agent manually after \
                   conversion.");
 
+    (* Install Balloon Server unconditionally and warn if missing *)
+    if not (Inject_virtio_win.inject_blnsvr virtio_win) then
+      warning (f_"Balloon Server (blnsvr.exe) not found on tools \
+                  ISO/directory. You may want to install this component \
+                  manually after conversion.");
+
     unconfigure_xenpv ();
     unconfigure_prltools ();
     unconfigure_vmwaretools ()
@@ -391,7 +400,7 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
                      %systemroot%\\Sysnative\\PnPutil -i -a \
                      %systemroot%\\Drivers\\Virtio\\*.inf" in
 
-    (* Set priority higher than that of "v2vnetcf.ps1" firstboot script. *)
+    (* Set priority higher than that of "network-configure" firstboot script. *)
     Firstboot.add_firstboot_script g inspect.i_root ~prio:2000
       "pnputil install drivers" fb_script;
 
@@ -624,43 +633,96 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
      *)
     let node =
       Registry.get_node reg ["Microsoft"; "Windows"; "CurrentVersion"] in
-    match node with
-    | Some node ->
-       let append = Registry.encode_utf16le ";%SystemRoot%\\Drivers\\VirtIO" in
-       let values = Array.to_list (g#hivex_node_values node) in
-       let rec loop = function
-         | [] -> () (* DevicePath not found -- ignore this case *)
-         | { G.hivex_value_h = valueh } :: values ->
-            let key = g#hivex_value_key valueh in
-            if key <> "DevicePath" then
-              loop values
-            else (
-              let data = g#hivex_value_value valueh in
-              let len = String.length data in
-              let t = g#hivex_value_type valueh in
+    (match node with
+     | Some node ->
+        let append = Registry.encode_utf16le ";%SystemRoot%\\Drivers\\VirtIO" in
+        let values = Array.to_list (g#hivex_node_values node) in
+        let rec loop = function
+          | [] -> () (* DevicePath not found -- ignore this case *)
+          | { G.hivex_value_h = valueh } :: values ->
+             let key = g#hivex_value_key valueh in
+             if key <> "DevicePath" then
+               loop values
+             else (
+               let data = g#hivex_value_value valueh in
+               let len = String.length data in
+               let t = g#hivex_value_type valueh in
 
-              (* Only add the appended path if it doesn't exist already. *)
-              if String.find data append = -1 then (
-                (* Remove the explicit [\0\0] at the end of the string.
-                 * This is the UTF-16LE NUL-terminator.
-                 *)
-                let data =
-                  if len >= 2 && String.sub data (len-2) 2 = "\000\000" then
-                    String.sub data 0 (len-2)
-                  else
-                    data in
+               (* Only add the appended path if it doesn't exist already. *)
+               if String.find data append = -1 then (
+                 (* Remove the explicit [\0\0] at the end of the string.
+                  * This is the UTF-16LE NUL-terminator.
+                  *)
+                 let data =
+                   if len >= 2 && String.sub data (len-2) 2 = "\000\000" then
+                     String.sub data 0 (len-2)
+                   else
+                     data in
 
-                (* Append the path and the explicit NUL. *)
-                let data = data ^ append ^ "\000\000" in
+                 (* Append the path and the explicit NUL. *)
+                 let data = data ^ append ^ "\000\000" in
 
-                g#hivex_node_set_value node key t data
-              )
-            )
-       in
-       loop values
-    | None ->
-       warning (f_"could not find registry key \
-                   HKLM\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion")
+                 g#hivex_node_set_value node key t data
+               )
+             )
+        in
+        loop values
+     | None ->
+        warning (f_"could not find registry key \
+                    HKLM\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion")
+    );
+
+    (* If you have trouble installing drivers, try increasing the
+     * verboseness by uncommenting this section.
+     * https://learn.microsoft.com/en-us/windows-hardware/drivers/install/setting-setupapi-logging-levels
+     * The additional logs are written to C:\Windows\INF\setupapi.*.log
+     *)
+(*
+    let node =
+      Registry.get_node reg ["Microsoft"; "Windows"; "CurrentVersion";
+                             "Setup"] in
+    (match node with
+     | Some node ->
+        g#hivex_node_set_value node "LogLevel" 4_L (le32_of_int 0xff_L)
+     | None ->
+        warning (f_"could not find registry key \
+                    HKLM\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Setup")
+    );
+*)
+
+  and configure_online_disks block_driver =
+    (* If there are > 1 disks, run a script which will force Windows
+     * to bring them all online.  Windows 2022 will offline non-boot disks
+     * where the bus changes as some sort of "security" mitigation.
+     * https://issues.redhat.com/browse/RHEL-55837
+     * https://issues.redhat.com/browse/MTV-1299
+     * https://bugzilla.redhat.com/show_bug.cgi?id=1662286
+     *)
+    let virtio_installed =
+      match block_driver with
+      | Inject_virtio_win.Virtio_blk | Virtio_SCSI -> true
+      | IDE -> false in
+    let more_than_one_disk = List.length source.s_disks > 1 in
+
+    if virtio_installed && more_than_one_disk then (
+      let psh_filename = "online-disks" in
+      let psh = ref [] in
+      let add = List.push_back psh in
+
+      add "# Uncomment this line for lots of debug output.";
+      add "# Set-PSDebug -Trace 1";
+      add "";
+      add "Write-Host \"Online all virtio disks\"";
+      add "";
+      add "Get-Disk | Where { $_.FriendlyName -like '*VirtIO*' } | % {";
+      add "    Write-Host ('  - ' + $_.Number + ': ' + $_.FriendlyName + '(' + [math]::Round($_.Size/1GB,2) + 'GB)')";
+      add "    $_ | Set-Disk -IsOffline $false";
+      add "    $_ | Set-Disk -IsReadOnly $false";
+      add "}";
+
+      (* Install the Powershell script to run late at firstboot. *)
+      Firstboot.add_firstboot_powershell g inspect.i_root psh_filename !psh
+    )
 
   and configure_network_interfaces net_driver =
     (* If we were asked to force network interfaces to have particular
@@ -668,7 +730,7 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
      * Powershell script which runs at boot.
      *)
     if static_ips <> [] then (
-      let psh_filename = "v2vnetcf.ps1" in
+      let psh_filename = "network-configure" in
       let psh = ref [] in
       let add = List.push_back psh in
 
@@ -681,13 +743,16 @@ let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
        *)
       if net_driver = Virtio_net then (
         add "# Wait for the netkvm (virtio-net) driver to become active.";
+        add "$startdate = Get-Date";
         add "$adapters = @()";
-        add "While (-Not $adapters) {";
+        add "While (-Not $adapters -and \
+                    $startdate.AddMinutes(5) -gt (Get-Date)) {";
         add "    Start-Sleep -Seconds 5";
         add "    $adapters = Get-NetAdapter -Physical \
                              | Where DriverFileName -eq \"netkvm.sys\"";
         add "    Write-Host \"adapters = '$adapters'\"";
         add "}";
+        add "# In the timeout case $ifindex will not be set below.";
         add ""
       );
 
