@@ -91,10 +91,10 @@ let rec main () =
     | "ip" ->
        (match String.nsplit "," out with
         | [] -> error (f_"invalid --mac ip option")
-        | [ip] -> add_static_ip mac ip None None []
-        | [ip; gw] -> add_static_ip mac ip (Some gw) None []
+        | [ip] -> add_static_ip mac ip "" "" []
+        | [ip; gw] -> add_static_ip mac ip gw "" []
         | ip :: gw :: len :: nameservers ->
-           add_static_ip mac ip (Some gw) (Some len) nameservers
+           add_static_ip mac ip gw len nameservers
        )
     | _ -> assert false
   and add_static_ip if_mac_addr if_ip_address if_default_gateway
@@ -109,12 +109,14 @@ let rec main () =
                   an IP address") what addr
     in
     error_unless_ip_addr "ipaddr" if_ip_address;
+    let if_default_gateway =
+      match if_default_gateway with "" -> None | gw -> Some gw in
     Option.iter (error_unless_ip_addr "gw") if_default_gateway;
     List.iter (error_unless_ip_addr "nameserver") if_nameservers;
     let if_prefix_length =
       match if_prefix_length_str with
-      | None -> None
-      | Some len ->
+      | "" -> None
+      | len ->
          let len =
            try int_of_string len with
            | Failure _ -> error (f_"cannot parse --mac ip prefix length \
@@ -178,6 +180,14 @@ let rec main () =
     [ L"root" ],     Getopt.String ("ask|... ", set_root_choice),
                                     s_"How to choose root filesystem";
   ] in
+
+  (* Append virt-customize options. *)
+  let customize_argspec, get_customize_ops =
+    Customize_cmdline.argspec ~v2v:true () in
+  let customize_argspec =
+    List.map (fun (spec, _, _) -> spec) customize_argspec in
+  let argspec = argspec @ customize_argspec in
+
   let args = ref [] in
   let anon_fun s = List.push_front s args in
   let usage_msg =
@@ -195,18 +205,19 @@ A short summary of the options is given below.  For detailed help please
 read the man page virt-v2v-in-place(1).
 ")
       prog in
+
   let opthandle = create_standard_options argspec ~anon_fun ~key_opts:true ~machine_readable:true usage_msg in
   Getopt.parse opthandle.getopt;
 
   (* Print the version, easier than asking users to tell us. *)
-  debug "%s: %s %s (%s)"
+  debug "info: %s: %s %s (%s)"
         prog Config.package_name Config.package_version_full
         Config.host_cpu;
 
   (* Print the libvirt version if debugging. *)
   if verbose () then (
     let major, minor, release = Libvirt_utils.libvirt_get_version () in
-    debug "libvirt version: %d.%d.%d" major minor release
+    debug "info: libvirt version: %d.%d.%d" major minor release
   );
 
   (* Create the v2v directory to control conversion. *)
@@ -220,6 +231,7 @@ read the man page virt-v2v-in-place(1).
     | Some "virtio-scsi" -> Virtio_SCSI
     | Some driver ->
        error (f_"unknown block driver ‘--block-driver %s’") driver in
+  let customize_ops = get_customize_ops () in
   let input_conn = !input_conn in
   let input_mode = !input_mode in
   let print_source = !print_source in
@@ -239,6 +251,7 @@ read the man page virt-v2v-in-place(1).
       pr "io\n";
       pr "mac-option\n";
       pr "mac-ip-option\n";
+      pr "customize-ops\n";
       pr "input:disk\n";
       pr "input:libvirt\n";
       pr "input:libvirtxml\n";
@@ -309,6 +322,7 @@ read the man page virt-v2v-in-place(1).
     network_map;
     root_choice;
     static_ips;
+    customize_ops;
   } in
 
   (* Before starting the input module, check there is sufficient
