@@ -28,23 +28,23 @@ open Utils
 let nbdkit_min_version = (1, 12, 0)
 
 type password =
-| NoPassword                    (* no password option at all *)
-| AskForPassword                (* password=- *)
-| PasswordFile of string        (* password=+file *)
+  | AskForPassword
+  | PasswordFile of string
 
-let error_unless_nbdkit_version_ge config min_version =
-  let version = Nbdkit.version config in
+let error_unless_nbdkit_version_ge min_version =
+  let version = Nbdkit.version () in
   if version < min_version then (
     let min_major, min_minor, min_release = min_version in
     error (f_"nbdkit is too old.  nbdkit >= %d.%d.%d is required.")
           min_major min_minor min_release
   )
 
-let error_unless_nbdkit_min_version config =
-  error_unless_nbdkit_version_ge config nbdkit_min_version
+let error_unless_nbdkit_min_version () =
+  error_unless_nbdkit_version_ge nbdkit_min_version
 
 (* Create an nbdkit module specialized for reading from SSH sources. *)
-let create_ssh ?bandwidth ?cor ~password ?port ~server ?user path =
+let create_ssh ?bandwidth ?cor ?(retry=true)
+      ~server ?port ?user ?password path =
   if not (Nbdkit.is_installed ()) then
     error (f_"nbdkit is not installed or not working");
 
@@ -54,8 +54,7 @@ let create_ssh ?bandwidth ?cor ~password ?port ~server ?user path =
   if not (Nbdkit.probe_filter "cow") then
     error (f_"nbdkit-cow-filter is not installed or not working");
 
-  let config = Nbdkit.config () in
-  error_unless_nbdkit_min_version config;
+  error_unless_nbdkit_min_version ();
 
   (* Construct the nbdkit command. *)
   let cmd = Nbdkit.create "ssh" in
@@ -67,7 +66,8 @@ let create_ssh ?bandwidth ?cor ~password ?port ~server ?user path =
   (* Retry filter (if it exists) can be used to get around brief
    * interruptions in service.  It must be closest to the plugin.
    *)
-  Nbdkit.add_filter_if_available cmd "retry";
+  if retry then
+    Nbdkit.add_filter_if_available cmd "retry";
 
   (* Caching extents speeds up qemu-img, especially its consecutive
    * block_status requests with req_one=1.
@@ -106,8 +106,8 @@ let create_ssh ?bandwidth ?cor ~password ?port ~server ?user path =
 
   (* Handle the password parameter specially. *)
   (match password with
-   | NoPassword -> ()
-   | AskForPassword ->
+   | None -> ()
+   | Some AskForPassword ->
       (* Because we will start nbdkit in the background and then wait
        * for 30 seconds for it to start up, we cannot use the
        * password=- feature of nbdkit to read the password
@@ -128,7 +128,7 @@ let create_ssh ?bandwidth ?cor ~password ?port ~server ?user path =
       On_exit.unlink password_file;
       with_open_out password_file (fun chan -> output_string chan password);
       Nbdkit.add_arg cmd "password" ("+" ^ password_file)
-   | PasswordFile password_file ->
+   | Some (PasswordFile password_file) ->
       Nbdkit.add_arg cmd "password" ("+" ^ password_file)
   );
 
