@@ -18,17 +18,17 @@
 
 (** nbdkit when used as a source. *)
 
-type password =
-| NoPassword
-| AskForPassword
-| PasswordFile of string
+type password =                 (** Use [None] for no password *)
+  | AskForPassword              (** [password=-] *)
+  | PasswordFile of string      (** [password=+file] *)
 
 val create_ssh : ?bandwidth:Types.bandwidth ->
                  ?cor:string ->
-                 password:password ->
-                 ?port:string ->
+                 ?retry:bool ->
                  server:string ->
+                 ?port:string ->
                  ?user:string ->
+                 ?password:password ->
                  string -> Nbdkit.cmd
 (** Create a nbdkit object using the SSH plugin.  The required
     string parameter is the remote path.
