@@ -18,13 +18,8 @@
 
 type vmx_source =
   | File of string              (** local file or NFS *)
-  | SSH of Xml.uri              (** SSH URI *)
+  | SSH of Nbdkit_ssh.password option * Xml.uri (** SSH URI *)
 
-val vmx_source_of_arg : [`SSH] option -> string -> vmx_source
+val vmx_source_of_arg : Nbdkit_ssh.password option -> [`SSH] option ->
+                        string -> vmx_source
 val parse_domain_from_vmx : vmx_source -> Types.source * string list
-
-(* XXX Exporting these is a hack. *)
-val path_of_uri : Xml.uri -> string
-val server_of_uri : Xml.uri -> string
-val port_of_uri : Xml.uri -> int option
-val remote_file_exists : Xml.uri -> string -> bool
