@@ -97,10 +97,10 @@ let rec main () =
     | "ip" ->
        (match String.nsplit "," out with
         | [] -> error (f_"invalid --mac ip option")
-        | [ip] -> add_static_ip mac ip None None []
-        | [ip; gw] -> add_static_ip mac ip (Some gw) None []
+        | [ip] -> add_static_ip mac ip "" "" []
+        | [ip; gw] -> add_static_ip mac ip gw "" []
         | ip :: gw :: len :: nameservers ->
-           add_static_ip mac ip (Some gw) (Some len) nameservers
+           add_static_ip mac ip gw len nameservers
        )
     | _ -> assert false
   and add_static_ip if_mac_addr if_ip_address if_default_gateway
@@ -115,12 +115,14 @@ let rec main () =
                   is an IP address") what addr
     in
     error_unless_ip_addr "ipaddr" if_ip_address;
+    let if_default_gateway =
+      match if_default_gateway with "" -> None | gw -> Some gw in
     Option.iter (error_unless_ip_addr "gw") if_default_gateway;
     List.iter (error_unless_ip_addr "nameserver") if_nameservers;
     let if_prefix_length =
       match if_prefix_length_str with
-      | None -> None
-      | Some len ->
+      | "" -> None
+      | len ->
          let len =
            try int_of_string len with
            | Failure _ -> error (f_"cannot parse --mac ip prefix \
@@ -181,6 +183,14 @@ let rec main () =
     [ S 'O' ],       Getopt.String ("output.xml", set_output_file_option),
                                     s_"Set the output filename";
   ] in
+
+  (* Append virt-customize options. *)
+  let customize_argspec, get_customize_ops =
+    Customize_cmdline.argspec ~v2v:true () in
+  let customize_argspec =
+    List.map (fun (spec, _, _) -> spec) customize_argspec in
+  let argspec = argspec @ customize_argspec in
+
   let args = ref [] in
   let anon_fun s = List.push_front s args in
   let usage_msg =
@@ -193,19 +203,20 @@ A short summary of the options is given below.  For detailed help please
 read the man page virt-v2v-inspector(1).
 ")
       prog in
+
   let opthandle = create_standard_options argspec ~anon_fun ~key_opts:true
                     ~machine_readable:true usage_msg in
   Getopt.parse opthandle.getopt;
 
   (* Print the version, easier than asking users to tell us. *)
-  debug "%s: %s %s (%s)"
+  debug "info: %s: %s %s (%s)"
         prog Config.package_name Config.package_version_full
         Config.host_cpu;
 
   (* Print the libvirt version if debugging. *)
   if verbose () then (
     let major, minor, release = Libvirt_utils.libvirt_get_version () in
-    debug "libvirt version: %d.%d.%d" major minor release
+    debug "info: libvirt version: %d.%d.%d" major minor release
   );
 
   (* Create the v2v directory to control conversion. *)
@@ -213,6 +224,7 @@ read the man page virt-v2v-inspector(1).
 
   (* Dereference the arguments. *)
   let args = List.rev !args in
+  let customize_ops = get_customize_ops () in
   let output_file = !output_file in
   let input_conn = !input_conn in
   let input_mode = !input_mode in
@@ -237,6 +249,7 @@ read the man page virt-v2v-inspector(1).
       pr "io\n";
       pr "mac-option\n";
       pr "mac-ip-option\n";
+      pr "customize-ops\n";
       pr "input:disk\n";
       pr "input:libvirt\n";
       pr "input:libvirtxml\n";
@@ -330,6 +343,7 @@ read the man page virt-v2v-inspector(1).
     network_map;
     root_choice;
     static_ips;
+    customize_ops;
   } in
 
   (* Before starting the input module, check there is sufficient
@@ -344,7 +358,7 @@ read the man page virt-v2v-inspector(1).
 
   (* Do the conversion. *)
   with_open_out (v2vdir // "convert") (fun _ -> ());
-  let inspect, _ = Convert.convert v2vdir conv_options source in
+  let inspect, target_meta = Convert.convert v2vdir conv_options source in
   unlink (v2vdir // "convert");
 
   (* Debug the v2vdir. *)
@@ -354,7 +368,7 @@ read the man page virt-v2v-inspector(1).
   );
 
   (* Dump out the information. *)
-  let doc = inspector_xml v2vdir inspect in
+  let doc = inspector_xml v2vdir inspect target_meta in
   let chan =
     match output_file with
     | None -> Stdlib.stdout
@@ -441,7 +455,7 @@ and get_input_disk_allocated dir i =
  *   - The NBD input sockets: v2vdir // "in0", "in1", etc
  *   - The inspection data (Types.inspect)
  *)
-and inspector_xml v2vdir inspect =
+and inspector_xml v2vdir inspect target_meta =
   let body = ref [] in
 
   (* Record the version of virt-v2v etc, mainly for debugging. *)
@@ -471,6 +485,16 @@ and inspector_xml v2vdir inspect =
   ) (get_disks v2vdir);
   List.push_back body (e "disks" [] !disks);
 
+  (* The <firmware> field is outside the <operatingsystem> element,
+   * since firmware is not part of the OS, and also because this is
+   * consistent with virt-drivers output.
+   *)
+  List.push_back body
+    (e "firmware"
+       ["type",
+        string_of_target_firmware target_meta.target_firmware]
+       []);
+
   (* The inspection data. *)
   (* NB: Keep these field names compatible with virt-inspector! *)
   let os = ref [] in
@@ -490,6 +514,31 @@ and inspector_xml v2vdir inspect =
                          [PCData inspect.i_package_management]);
   if inspect.i_product_name <> "" then
     List.push_back os (e "product_name" [] [PCData inspect.i_product_name]);
+  if inspect.i_product_variant <> "" then
+    List.push_back os (e "product_variant" []
+                         [PCData inspect.i_product_variant]);
+
+  if inspect.i_windows_systemroot <> "" then
+    List.push_back os (e "windows_systemroot" []
+                         [PCData inspect.i_windows_systemroot]);
+  if inspect.i_windows_software_hive <> "" then
+    List.push_back os (e "windows_software_hive" []
+                         [PCData inspect.i_windows_software_hive]);
+  if inspect.i_windows_systemroot <> "" then
+    List.push_back os (e "windows_system_hive" []
+                         [PCData inspect.i_windows_system_hive]);
+  if inspect.i_windows_current_control_set <> "" then
+    List.push_back os (e "windows_current_control_set" []
+                         [PCData inspect.i_windows_current_control_set]);
+
+  List.push_back os (e "root" [] [PCData inspect.i_root]);
+  let mps = ref [] in
+  List.iter (
+    fun (fs, dev) ->
+      List.push_back mps (e "mountpoint" [ "dev", dev ] [PCData fs])
+  ) inspect.i_mountpoints;
+  List.push_back os (e "mountpoints" [] !mps);
+
   List.push_back body (e "operatingsystem" [] !os);
 
   (* Construct the final document. *)
