@@ -159,6 +159,7 @@ and source_cpu_topology = {
 val string_of_source : source -> string
 val string_of_source_disk : source_disk -> string
 val string_of_controller : s_controller -> string
+val string_of_source_nic : source_nic -> string
 val string_of_nic_model : s_nic_model -> string
 val nic_model_of_string : string -> s_nic_model
 val string_of_vnet_type : vnet_type -> string
@@ -193,6 +194,7 @@ type inspect = {
   i_windows_software_hive : string;
   i_windows_system_hive : string;
   i_windows_current_control_set : string;
+  i_drive_mappings : (string * string) list;
 }
 
 val string_of_inspect : inspect -> string
