@@ -1,5 +1,5 @@
 (* virt-v2v
- * Copyright (C) 2009-2020 Red Hat Inc.
+ * Copyright (C) 2009-2024 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,9 @@ open DOM
 let string_set_of_list =
   List.fold_left (fun set x -> StringSet.add x set) StringSet.empty
 
+(* XXX libguestfs provides g#inspect_get_osinfo which provides this
+ * information.  Why are we hard-coding it here?
+ *)
 let get_osinfo_id = function
   | { i_type = "linux"; i_distro = "rhel";
       i_major_version = major; i_minor_version = minor } ->
@@ -47,6 +50,10 @@ let get_osinfo_id = function
     when major >= 8 ->
     Some (sprintf "http://centos.org/centos/%d" major)
 
+  | { i_type = "linux"; i_distro = "circle";
+      i_major_version = major; i_minor_version = minor } ->
+    Some (sprintf "http://cclinux.org/circle/%d.%d" major minor)
+
   | { i_type = "linux"; i_distro = "rocky";
       i_major_version = major; i_minor_version = minor } ->
     Some (sprintf "http://rockylinux.org/rocky/%d.%d" major minor)
@@ -134,6 +141,11 @@ let get_osinfo_id = function
       when String.find product "2019" >= 0 ->
     Some "http://microsoft.com/win/2k19"
 
+  | { i_type = "windows"; i_major_version = 10; i_minor_version = 0;
+      i_product_variant = "Server"; i_product_name = product }
+      when String.find product "2022" >= 0 ->
+    Some "http://microsoft.com/win/2k22"
+
   | { i_type = "windows"; i_major_version = 10; i_minor_version = 0;
       i_product_variant = "Server" } ->
     Some "http://microsoft.com/win/2k16"
@@ -214,23 +226,6 @@ let create_libvirt_xml ?pool source inspect
 
   List.push_back_list body [ e "cpu" !cpu_attrs !cpu ];
 
-  let uefi_firmware =
-    match target_firmware with
-    | TargetBIOS -> None
-    | TargetUEFI -> Some (find_uefi_firmware guestcaps.gcaps_arch) in
-  let machine, secure_boot_required =
-    match guestcaps.gcaps_machine, uefi_firmware with
-    | _, Some { Uefi.flags = flags }
-         when List.mem Uefi.UEFI_FLAG_SECURE_BOOT_REQUIRED flags ->
-       (* Force machine type to Q35 because PC does not support
-        * secure boot.  We must remove this when we get the
-        * correct machine type from libosinfo in future. XXX
-        *)
-       Q35, true
-    | machine, _ ->
-       machine, false in
-  let smm = secure_boot_required in
-
   (* We have the machine features of the guest when it was on the
    * source hypervisor (source.s_features).  We have the set of
    * hypervisor features supported by the target (target_features).
@@ -253,13 +248,6 @@ let create_libvirt_xml ?pool source inspect
     StringSet.inter(*section*) force_features target_features in
   let features = StringSet.union features force_features in
 
-  (* Add <smm> feature if UEFI requires it.  Note that libvirt
-   * capabilities doesn't list this feature even if it is supported
-   * by qemu, so we have to blindly add it, which might cause libvirt
-   * to fail. (XXX)
-   *)
-  let features = if smm then StringSet.add "smm" features else features in
-
   let features = List.sort compare (StringSet.elements features) in
 
   List.push_back_list body [
@@ -270,8 +258,13 @@ let create_libvirt_xml ?pool source inspect
   let os_section =
     let os = ref [] in
 
+    let firmware =
+      match target_firmware with
+      | TargetBIOS -> []
+      | TargetUEFI -> [ "firmware", "efi" ] in
+
     let machine =
-      match machine with
+      match guestcaps.gcaps_machine with
       | I440FX -> "pc"
       | Q35 -> "q35"
       | Virt -> "virt" in
@@ -281,18 +274,11 @@ let create_libvirt_xml ?pool source inspect
                               "machine", machine]
                       [PCData "hvm"]);
 
-    let loader =
-      match uefi_firmware with
-      | None -> []
-      | Some { Uefi.code = code; vars = vars_template } ->
-         let secure =
-           if secure_boot_required then [ "secure", "yes" ] else [] in
-         [ e "loader" (["readonly", "yes"; "type", "pflash"] @ secure)
-             [ PCData code ];
-           e "nvram" ["template", vars_template] [] ] in
-
-    List.push_back_list os loader;
-    e "os" [] !os in
+    (* We used to sometimes put <loader secure='yes'/> here.  However
+     * that is likely wrong since by its nature virt-v2v can't really
+     * support secure boot ever.  So for now we omit it.
+     *)
+    e "os" firmware !os in
 
   (* The <clock> section. *)
   let clock_section =
