@@ -110,10 +110,10 @@ let rec main () =
     | "ip" ->
        (match String.nsplit "," out with
         | [] -> error (f_"invalid --mac ip option")
-        | [ip] -> add_static_ip mac ip None None []
-        | [ip; gw] -> add_static_ip mac ip (Some gw) None []
+        | [ip] -> add_static_ip mac ip "" "" []
+        | [ip; gw] -> add_static_ip mac ip gw "" []
         | ip :: gw :: len :: nameservers ->
-           add_static_ip mac ip (Some gw) (Some len) nameservers
+           add_static_ip mac ip gw len nameservers
        )
     | _ -> assert false
   and add_static_ip if_mac_addr if_ip_address if_default_gateway
@@ -128,12 +128,14 @@ let rec main () =
                   is an IP address") what addr
     in
     error_unless_ip_addr "ipaddr" if_ip_address;
+    let if_default_gateway =
+      match if_default_gateway with "" -> None | gw -> Some gw in
     Option.iter (error_unless_ip_addr "gw") if_default_gateway;
     List.iter (error_unless_ip_addr "nameserver") if_nameservers;
     let if_prefix_length =
       match if_prefix_length_str with
-      | None -> None
-      | Some len ->
+      | "" -> None
+      | len ->
          let len =
            try int_of_string len with
            | Failure _ -> error (f_"cannot parse --mac ip prefix length field \
@@ -310,6 +312,14 @@ let rec main () =
     [ L"vmtype" ],   Getopt.String ("-", vmtype_warning),
       s_"Ignored for backwards compatibility";
   ] in
+
+  (* Append virt-customize options. *)
+  let customize_argspec, get_customize_ops =
+    Customize_cmdline.argspec ~v2v:true () in
+  let customize_argspec =
+    List.map (fun (spec, _, _) -> spec) customize_argspec in
+  let argspec = argspec @ customize_argspec in
+
   let args = ref [] in
   let anon_fun s = List.push_front s args in
   let usage_msg =
@@ -334,19 +344,20 @@ A short summary of the options is given below.  For detailed help please
 read the man page virt-v2v(1).
 ")
       prog in
+
   let opthandle = create_standard_options argspec ~anon_fun ~key_opts:true
                     ~machine_readable:true usage_msg in
   Getopt.parse opthandle.getopt;
 
   (* Print the version, easier than asking users to tell us. *)
-  debug "%s: %s %s (%s)"
+  debug "info: %s: %s %s (%s)"
         prog Config.package_name Config.package_version_full
         Config.host_cpu;
 
   (* Print the libvirt version if debugging. *)
   if verbose () then (
     let major, minor, release = Libvirt_utils.libvirt_get_version () in
-    debug "libvirt version: %d.%d.%d" major minor release
+    debug "info: libvirt version: %d.%d.%d" major minor release
   );
 
   (* Create the temporary directory to control conversion. *)
@@ -360,6 +371,7 @@ read the man page virt-v2v(1).
     | Some "virtio-scsi" -> Virtio_SCSI
     | Some driver ->
        error (f_"unknown block driver ‘--block-driver %s’") driver in
+  let customize_ops = get_customize_ops () in
   let input_conn = !input_conn in
   let input_mode = !input_mode in
   let input_transport =
@@ -396,6 +408,7 @@ read the man page virt-v2v(1).
       pr "mac-option\n";
       pr "bandwidth-option\n";
       pr "mac-ip-option\n";
+      pr "customize-ops\n";
       pr "input:disk\n";
       pr "input:libvirt\n";
       pr "input:libvirtxml\n";
@@ -539,6 +552,7 @@ read the man page virt-v2v(1).
     network_map;
     root_choice;
     static_ips;
+    customize_ops;
   } in
 
   (* Before starting the input module, check there is sufficient
@@ -609,8 +623,13 @@ read the man page virt-v2v(1).
        * side of the pipeline.
        *)
       if verbose () then (
-        nbdinfo ~content:true input_uri;
-        nbdinfo ~content:false output_uri
+        let input_info = nbdinfo ~content:true input_uri
+        and output_info = nbdinfo ~content:false output_uri in
+        eprintf "info: input disk %d/%d:\n" (i+1) nr_disks;
+        eprintf "%s\n" (String.concat "\n" input_info);
+        eprintf "info: output disk %d/%d:\n" (i+1) nr_disks;
+        eprintf "%s\n" (String.concat "\n" output_info);
+        flush Stdlib.stderr
       );
 
       nbdcopy ?request_size output_alloc input_uri output_uri
@@ -684,15 +703,14 @@ and nbdcopy ?request_size output_alloc input_uri output_uri =
   if run_command cmd <> 0 then
     error (f_"nbdcopy command failed, see earlier error messages")
 
-(* Run nbdinfo on a URI and dump the information to stderr.
- * However don't fail if nbdinfo is not installed since
- * this is just used for debugging.
+(* Run nbdinfo on a URI and collect the information.  However don't
+ * fail if nbdinfo is not installed since this is just used for debugging.
  *)
 and nbdinfo ?(content = false) uri =
   let cmd =
-    sprintf "nbdinfo%s %s >&2"
+    sprintf "nbdinfo%s %s ||:"
       (if content then " --content" else " --no-content") (quote uri) in
-  ignore (Sys.command cmd)
+  external_command cmd
 
 (* Convert a Unix domain socket path to an NBD URI. *)
 and nbd_uri_of_socket = sprintf "nbd+unix:///?socket=%s"
